#!/usr/bin/env python
# $Id: $

import susan

class MenuLayout(susan.BoardLayout):
    def __init__(self):
        super(MenuLayout, self).__init__([2, 2, 4])
        p0 = 1 - self.cell_owners[0]
        p1 = 1 - self.cell_owners[1]

        self.initial_state = [susan.CELL_EMPTY for i in range(self.ncells)]
        self.initial_state[0] = p0
        self.initial_state[1] = p1

        import game
        self.cell_player = {
            0: None,
            1: None,
            2: None,
            3: lambda win: game.HumanPlayer(win, p0),
            4: None,
            5: lambda win: game.HumanPlayer(win, p1),
            6: lambda win: game.TutorComputerPlayer(win, p0),
            7: lambda win: game.ComputerPlayer(win, p0, 2),
            8: lambda win: game.ComputerPlayer(win, p0, 3),
            9: lambda win: game.ComputerPlayer(win, p0, 4),
            14: lambda win: game.ComputerPlayer(win, p1, 1),
            15: lambda win: game.ComputerPlayer(win, p1, 2),
            16: lambda win: game.ComputerPlayer(win, p1, 3),
            17: lambda win: game.ComputerPlayer(win, p1, 4),
        }


    def can_move(self, state, cellfrom, cellto):
        if cellfrom == cellto:
            return False
        if self.cell_owners[cellto] != 1 - state[cellfrom]:
            return False
        if cellto not in self.cell_player:
            return False
        return True

    def get_players(self, win, state):
        assert self.is_valid(state)
        players = [None, None]
        for cell, piece in enumerate(state):
            if piece != susan.CELL_EMPTY:
                players[piece] = self.cell_player.get(cell, None)(win)
        import game
        if isinstance(players[1], game.TutorComputerPlayer) and \
           isinstance(players[0], game.ComputerPlayer):
            players[1] = game.ComputerPlayer(win, 1, 1)

        return players

    def is_valid(self, state):
        players = [None, None]
        for cell, piece in enumerate(state):
            if piece != susan.CELL_EMPTY:
                players[piece] = self.cell_player.get(cell, None)
        if players[0] is None or players[1] is None:
            return False
        return True
